@@ -241,6 +241,8 @@ MS2_PUBLIC void ms_snd_card_manager_set_param_string(MSSndCardManager *m, const
 
 /**
  * Retreive a sound card object based on it's id.
+ * The id can be a regex string. In this case, the search will be done on "Driver_type : ID."
+ * eg: "PulseAudio?( .*)?:.*Build in.*" will retrieve a card with an ID that contains "Build in" and use the PulseAudio Driver.
  *
  * @param m    A sound card manager containing sound cards.
  * @param id   An id for card to search.
@@ -251,6 +253,8 @@ MS2_PUBLIC MSSndCard * ms_snd_card_manager_get_card(MSSndCardManager *m, const c
 
 /**
  * Retreive a sound card object based on it's id and capabilities.
+ * The id can be a regex string. In this case, the search will be done on "Filter : ID."
+ * eg: "PulseAudio?( .*)?:.*Build-in.*" will retrieve a card with an ID that contains "Build-in" in PulseAudio Filter.
  *
  * @param m    A sound card manager containing sound cards.
  * @param id   An id for card to search.
@@ -536,7 +540,7 @@ MS2_PUBLIC const char *ms_snd_card_get_name(const MSSndCard *obj);
  *
  * Returns: A string if successfull, NULL otherwise.
  */
-MS2_PUBLIC const char *ms_snd_card_get_string_id(MSSndCard *obj);
+MS2_PUBLIC const char *ms_snd_card_get_string_id(const MSSndCard *obj);
 
 /**
  * Retrieve sound card's internal ID.
@@ -547,6 +551,12 @@ MS2_PUBLIC const char *ms_snd_card_get_string_id(MSSndCard *obj);
  */
 MS2_PUBLIC int ms_snd_card_get_internal_id(MSSndCard *obj);
 
+/**
+ * Returns TRUE if both MSSndCard are equal, which means that they refer to the same
+ * audio device with same capabilities.
+ */
+MS2_PUBLIC bool_t ms_snd_card_equals(const MSSndCard *c1, const MSSndCard *c2);
+
 /**
  * Retreive sound card's capabilities.
  *
